Struct amazon_sp_merchant_fulfillment::models::available_carrier_will_pick_up_option::AvailableCarrierWillPickUpOption
source · [−]pub struct AvailableCarrierWillPickUpOption {
pub carrier_will_pick_up_option: CarrierWillPickUpOption,
pub charge: Box<CurrencyAmount>,
}Expand description
AvailableCarrierWillPickUpOption : Indicates whether the carrier will pick up the package, and what fee is charged, if any.
Fields
carrier_will_pick_up_option: CarrierWillPickUpOptioncharge: Box<CurrencyAmount>Implementations
sourceimpl AvailableCarrierWillPickUpOption
impl AvailableCarrierWillPickUpOption
sourcepub fn new(
carrier_will_pick_up_option: CarrierWillPickUpOption,
charge: CurrencyAmount
) -> AvailableCarrierWillPickUpOption
pub fn new(
carrier_will_pick_up_option: CarrierWillPickUpOption,
charge: CurrencyAmount
) -> AvailableCarrierWillPickUpOption
Indicates whether the carrier will pick up the package, and what fee is charged, if any.